summaryrefslogtreecommitdiffstats
path: root/service/java/com/android/server/wifi/DeviceConfigFacade.java
diff options
context:
space:
mode:
authorMingguang Xu <mingguangxu@google.com>2019-10-03 17:36:01 +0000
committerMingguang Xu <mingguangxu@google.com>2019-10-04 20:08:50 +0000
commit1bea2b5d4072cc068fbb120a9d7e9338adee74de (patch)
treee1a80cfb59d373558e35f5efd9096b2715b246b2 /service/java/com/android/server/wifi/DeviceConfigFacade.java
parentec1e58cd439ae645ff4e5bf55f7961e359bf0e4c (diff)
downloadandroid_frameworks_opt_net_wifi-1bea2b5d4072cc068fbb120a9d7e9338adee74de.tar.gz
android_frameworks_opt_net_wifi-1bea2b5d4072cc068fbb120a9d7e9338adee74de.tar.bz2
android_frameworks_opt_net_wifi-1bea2b5d4072cc068fbb120a9d7e9338adee74de.zip
Revert "Wifi usability: Change the unit of the threshold for tx/rx throughput from Mbps to Kbps"
This reverts commit ec1e58cd439ae645ff4e5bf55f7961e359bf0e4c. Reason for revert: This change introduced a bug and it completely changed the functionality of WiFi data stall detection, e.g., high Tx link speed can easily trigger data stall.  We would like to roll back them to restore the normal functionality of Wifi data stall detection. Bug: 141995185 Change-Id: I0a2ca9d20771296774af0196f7d0a147d7874249 Merged-In: I76d6338cd2d482d198fde1e5a2d1a0540c087ca6
Diffstat (limited to 'service/java/com/android/server/wifi/DeviceConfigFacade.java')
-rw-r--r--service/java/com/android/server/wifi/DeviceConfigFacade.java20
1 files changed, 10 insertions, 10 deletions
diff --git a/service/java/com/android/server/wifi/DeviceConfigFacade.java b/service/java/com/android/server/wifi/DeviceConfigFacade.java
index 947261b8a..a9889f424 100644
--- a/service/java/com/android/server/wifi/DeviceConfigFacade.java
+++ b/service/java/com/android/server/wifi/DeviceConfigFacade.java
@@ -31,10 +31,10 @@ public class DeviceConfigFacade {
// Default duration for evaluating Wifi condition to trigger a data stall
// measured in milliseconds
public static final int DEFAULT_DATA_STALL_DURATION_MS = 1500;
- // Default threshold of Tx throughput below which to trigger a data stall measured in Kbps
- public static final int DEFAULT_DATA_STALL_TX_TPUT_THR_KBPS = 2000;
- // Default threshold of Rx throughput below which to trigger a data stall measured in Kbps
- public static final int DEFAULT_DATA_STALL_RX_TPUT_THR_KBPS = 2000;
+ // Default threshold of Tx throughput below which to trigger a data stall measured in Mbps
+ public static final int DEFAULT_DATA_STALL_TX_TPUT_THR_MBPS = 2;
+ // Default threshold of Rx throughput below which to trigger a data stall measured in Mbps
+ public static final int DEFAULT_DATA_STALL_RX_TPUT_THR_MBPS = 2;
// Default threshold of Tx packet error rate above which to trigger a data stall in percentage
public static final int DEFAULT_DATA_STALL_TX_PER_THR = 90;
// Default threshold of CCA level above which to trigger a data stall in percentage
@@ -77,17 +77,17 @@ public class DeviceConfigFacade {
/**
* Gets the threshold of Tx throughput below which to trigger a data stall.
*/
- public int getDataStallTxTputThrKbps() {
- return DeviceConfig.getInt(NAMESPACE, "data_stall_tx_tput_thr_kbps",
- DEFAULT_DATA_STALL_TX_TPUT_THR_KBPS);
+ public int getDataStallTxTputThrMbps() {
+ return DeviceConfig.getInt(NAMESPACE, "data_stall_tx_tput_thr_mbps",
+ DEFAULT_DATA_STALL_TX_TPUT_THR_MBPS);
}
/**
* Gets the threshold of Rx throughput below which to trigger a data stall.
*/
- public int getDataStallRxTputThrKbps() {
- return DeviceConfig.getInt(NAMESPACE, "data_stall_rx_tput_thr_kbps",
- DEFAULT_DATA_STALL_RX_TPUT_THR_KBPS);
+ public int getDataStallRxTputThrMbps() {
+ return DeviceConfig.getInt(NAMESPACE, "data_stall_rx_tput_thr_mbps",
+ DEFAULT_DATA_STALL_RX_TPUT_THR_MBPS);
}
/**